
int   Save_RC();
int   Add_User (SOK_T sok, UDWORD uin, char *name);
void  Get_Unix_Config_Info (void);
void  Set_rcfile (const char * name);
